#!/bin/sh
 
#-------------------------------------------------------------------
# Licensed Material - Property of IBM
#
# 5724-J34 (C) Copyright IBM Corp. 2006,2007
# All Rights Reserved.
# U.S. Government users - RESTRICTED RIGHTS - Use, Duplication, or
# Disclosure restricted by GSA-ADP schedule contract with IBM Corp.
# Status = HEEX610
#
# -------------------------------------------------------------------------
# Parms
# $1 - Absolute path to install root
# $2 - Absoluate path to the config root
# Returns
#  0 - Success
# -1 - Failure
#
# Test Line
#
# Logic: This script does set up work for the Multi-Product PTF post installer.
 
# Get the current level from the WXDBASE.product file
 
function level {
 
iconv -fISO8859-1 -tIBM-1047 $InstallRoot/properties/version/WXDBASE.product > $tmpdir/WXDBASE.product.ebcdic
line=$(grep -I level $tmpdir/WXDBASE.product.ebcdic)
echo $line | awk '{ 
	cnt=split($0,tokens," ")
	i=0
	while ( i <= cnt ) {
	
	
		if ( match(tokens[i],"level") > 0 ) {
			split(tokens[i],levelKey,"=")
			split(levelKey[2],levelValue,"\"")
			print levelValue[2]
		}
		i++;
			
	}
}'
rm -rf $tmpdir/WXDBASE.product.ebcdic
}
 
# -------------------------------------------------------------------------
# Global Initialization 
# -------------------------------------------------------------------------
 
echo $0" - BEGIN - "$(date)

if [ -z $1 ]
then
   echo "Syntax: eexwpost.sh <SMP/E install root> <(writable) config root>"
   exit 8
fi

InstallRoot=$1

if [ ! -d $InstallRoot ]
then
   echo "$InstallRoot is not a valid directory"
   echo "Syntax: eexwpost.sh <SMP/E install root> <(writable) config root>"
   exit 8
fi

if [ -z $2 ]
then
   echo "Syntax: eexwpost.sh <SMP/E install root> <(writable) config root>"
   exit 8
fi

ConfigRoot=$2

if [ ! -d $ConfigRoot ]
then
   echo "$ConfigRoot is not a valid directory"
   echo "Syntax: eexwpost.sh <SMP/E install root> <(writable) config root>"
   exit 8
fi

if [ ! -w $ConfigRoot ]
then
   echo "$ConfigRoot must be writable"
   echo "Syntax: eexwpost.sh <SMP/E install root> <(writable) config root>"
   exit 8
fi
 
if [ ! -d $ConfigRoot/profiles/default ]
then
   echo "$ConfigRoot must contain a profile"
   echo "Syntax: eexwpost.sh <SMP/E install root> <(writable) config root>"
   exit 8
fi
 
if [ ! -e $ConfigRoot/profiles/default/bin/setupCmdLine.sh ]
then
   echo "Cannot find setupCmdLine.sh in $ConfigRoot/profiles/default/bin"
   echo "Syntax: eexwpost.sh <SMP/E install root> <(writable) config root>"
   exit 8
fi
 
coldstartlevel=$3

configtype=$4

. $ConfigRoot/profiles/default/bin/setupCmdLine.sh
 
tmpdir=$ConfigRoot/properties/service/product/WebSphereXD/backup/tmp

umask 002

wasproperties=$tmpdir/zWASPostInstaller.properties 
zWASPostInstaller=$ConfigRoot/properties/service/product/WebSphereXD/zXDBasePostInstaller.properties 
 
if [ ! -e $tmpdir ]; then
  mkdir -p $tmpdir
fi
 
if [ -e $wasproperties ]; then
  rm $wasproperties
fi
 
currentlevel=$(level)
 
if [ ! -z $coldstartlevel ]
then 
    currentlevel=$coldstartlevel
fi

if [ -z $configtype ]
then 
    configtype=$CONFIG_TYPE
fi
    
 
echo "#-------------------------------------------------------------------"       >> $wasproperties
echo "# Licensed Material - Property of IBM"                                      >> $wasproperties
echo "#"                                                                          >> $wasproperties
echo "# 5724-J37 Copyright IBM Corp. 2007"                                    >> $wasproperties
echo "# All Rights Reserved."                                                     >> $wasproperties
echo "# U.S. Government users - RESTRICTED RIGHTS - Use, Duplication, or"         >> $wasproperties
echo "# Disclosure restricted by GSA-ADP schedule contract with IBM Corp."        >> $wasproperties
echo "# Status = HEEXW601"                                                         >> $wasproperties
echo "#"                                                                          >> $wasproperties
echo "# ------------------------------------------------------------------"       >> $wasproperties
echo " "                                                                          >> $wasproperties
echo "# Multi-Product PTF Installer properties file for WebSphere  XD     "       >> $wasproperties
echo "# Date Created: "$(date)                                                    >> $wasproperties
echo " "                                                                          >> $wasproperties
echo "WAS.home="$ConfigRoot                                                       >> $wasproperties           
echo "XD.base.smpe.root="$InstallRoot                                                 >> $wasproperties
echo "XD.base.config.type="$configtype                                                >> $wasproperties
echo "XD.base.service.backup="$ConfigRoot"/properties/service/product/WebSphereXD/backup" >> $wasproperties
echo "XD.base.current.config.root.service.level="$currentlevel                        >> $wasproperties
echo "XD.base.coldstart.level="$currentlevel                                          >> $wasproperties
echo "XD.base.current.smpe.install.root.level="$currentlevel                          >> $wasproperties
echo "XD.base.target.rollback.level="                                                 >> $wasproperties
 
if [ -e $zWASPostInstaller ]; then
  rm $zWASPostInstaller
fi
 
# Now copy the properties file into the right place and convert it to ASCII
iconv -fIBM-1047 -tISO8859-1 $wasproperties > $zWASPostInstaller
 
# Copy the xd-base-service-level.properties file from the SMP/e root to this ConfigRoot
# so that applyPTF.sh doesn't think there is post install service pending
 
cp $InstallRoot/properties/service/product/WebSphereXD/service/service-level.properties $ConfigRoot/properties/service/product/WebSphereXD/service-level.properties
 
echo $0" - END - "$(date)
 
 
 
 
 
 
 
 
 
 
