//EEXALLOC JOB <JOB PARAMETERS>                                                 
//*********************************************************************         
//* Licensed Material - Property of IBM                               *         
//* 5655-P28,5655-S33 (C) Copyright IBM Corp. 2006,2007               *         
//*                                                                   *         
//* All Rights Reserved.                                              *         
//*                                                                   *         
//* U.S. Government users - RESTRICTED RIGHTS - Use, Duplication, or  *         
//* Disclosure restricted by GSA-ADP schedule contract with IBM Corp. *         
//*                                                                   *         
//* Status = HEEX610                                                  *         
//* _________________________________________________________________ *         
//*                                                                   *         
//*  This JCL will allocate the TARGET, DISTRIBUTION, and HFS         *         
//*  libraries for the WebSphere Extended Deployment for z/OS.        *         
//*                                                                   *         
//*  CAUTION: This is neither a JCL procedure nor a complete job.     *         
//*  Before using this job step, you will have to make the following  *         
//*  modifications:                                                   *         
//*                                                                   *         
//*  1) Add the job parameters to meet your system requirements       *         
//*                                                                   *         
//*  2) Change HLQ to the appropriate data set name prefix if you     *         
//*     choose not to use the default of EEX. For example, you could  *         
//*     specify HLQ=WAS or HLQ=EEX.V6R1M0; enclose the data set name  *         
//*     prefix in apostrophes if it contains special characters.      *         
//*                                                                   *         
//*  3) Change DSP variable to the appropriate final disposition of   *         
//*     the dataset ("CATLG" is the default) on the exec steps if     *         
//*     you choose not to use the default.                            *         
//*                                                                   *         
//*  4) This job uses the recommended data set placement for the      *         
//*     target libraries:                                             *         
//*     Change ttttt1 to the volser for volume for the target         *         
//*            libraries.                                             *         
//*                                                                   *         
//*  5) Change dddddd to the volser for the distribution libraries.   *         
//*                                                                   *         
//*  6) Change hhhhhh to the volser for the HFS library               *         
//*                                                                   *         
//*    If you specify a volume for any dataset in this job, you       *         
//*    must also specify the same volume in the corresponding         *         
//*    DDDEF entry in the DDDEF job, EEXDDDEF.                        *         
//*                                                                   *         
//*  7) This FMID contains PDSE and HFS data sets.  You must verify   *         
//*     your ACS routines to ensure that the data sets will be        *         
//*     allocated where appropriate for your environment.  The        *         
//*     default allocation of the PDSE(s) and HFS in this job is      *         
//*     non-SMS managed.  If you want non-SMS managed data sets       *         
//*     ensure that your ACS routines will not override the PDSE      *         
//*     and HFS allocation parameters and create SMS managed data     *         
//*     sets.  If you want SMS managed PDSE(s) and HFS, then verify   *         
//*     that the allocation will result in SMS managed data sets.     *         
//*                                                                   *         
//*  8) This product installs into its own HFS.                       *         
//*                                                                   *         
//*  Notes:                                                           *         
//*                                                                   *         
//*  1. This job will complete with a return code 0.  You must        *         
//*     check allocation messages to verify the data sets are         *         
//*     allocated and cataloged as expected.                          *         
//*                                                                   *         
//*  2. Run only the steps that are applicable to your                *         
//*     installation:                                                 *         
//*     Steps ALLOCT and ALLOCD contain all data sets                 *         
//*       as of WebSphere Extended Deployment for z/OS 6.1.0          *         
//*                                                                   *         
//*********************************************************************         
//*   Allocate Target libraries: WebSphere Extended Deployment for    *         
//*   z/OS 6.1.0                                                      *         
//*********************************************************************         
//ALLOCTGT PROC HLQ=,                                                           
//            DSP=,                                                             
//            TVOL1=                                                            
//*                                                                             
//ALLOCT1  EXEC PGM=IEFBR14                                                     
//*                                                                             
//SEEXEXEC DD DSN=&HLQ..SEEXEXEC,                                               
//            DISP=(NEW,&DSP.),                                                 
//            DCB=(RECFM=VB,LRECL=255,BLKSIZE=0),                               
//            UNIT=SYSALLDA,                                                    
//            VOL=SER=&TVOL1,                                                   
//            SPACE=(6160,(75,10,5))                                            
//*                                                                             
//SEEXJCL  DD DSN=&HLQ..SEEXJCL,                                                
//            DISP=(NEW,&DSP.),                                                 
//            DCB=(RECFM=FB,LRECL=80,BLKSIZE=0),                                
//            UNIT=SYSALLDA,                                                    
//            VOL=SER=&TVOL1,                                                   
//            SPACE=(6160,(75,10,5))                                            
//*                                                                             
//EALLOCT1 PEND                                                                 
//*                                                                             
//*********************************************************************         
//*   Allocate Distribution Libraries: WebSphere Extended Deployment  *         
//*   for z/OS 6.1.0                                                  *         
//*********************************************************************         
//*                                                                             
//ALLOCDLB PROC HLQ=,                                                           
//            DSP=,                                                             
//            DVOL=                                                             
//*                                                                             
//ALLOCD1  EXEC PGM=IEFBR14                                                     
//*                                                                             
//AEEXANT DD DSN=&HLQ..AEEXANT,                                                 
//            DISP=(NEW,&DSP.),                                                 
//            DCB=(RECFM=VB,LRECL=255,BLKSIZE=0),                               
//            UNIT=SYSALLDA,                                                    
//            VOL=SER=&DVOL,                                                    
//            SPACE=(6160,(30000,1000,350))                                     
//*                                                                             
//AEEXEBCD DD DSN=&HLQ..AEEXEBCD,                                               
//            DISP=(NEW,&DSP.),                                                 
//            DCB=(RECFM=VB,LRECL=31000,BLKSIZE=0),                             
//            UNIT=SYSALLDA,                                                    
//            VOL=SER=&DVOL,                                                    
//            SPACE=(6160,(1350,100,15))                                        
//*                                                                             
//AEEXEXEC DD DSN=&HLQ..AEEXEXEC,                                               
//            DISP=(NEW,&DSP.),                                                 
//            DCB=(RECFM=VB,LRECL=255,BLKSIZE=0),                               
//            UNIT=SYSALLDA,                                                    
//            VOL=SER=&DVOL,                                                    
//            SPACE=(6160,(75,10,5))                                            
//*                                                                             
//AEEXJCL  DD DSN=&HLQ..AEEXJCL,                                                
//            DISP=(NEW,&DSP.),                                                 
//            DCB=(RECFM=FB,LRECL=80,BLKSIZE=0),                                
//            UNIT=SYSALLDA,                                                    
//            VOL=SER=&DVOL,                                                    
//            SPACE=(6160,(75,10,5))                                            
//*                                                                             
//EALLOCD1 PEND                                                                 
//*                                                                             
//*********************************************************************         
//*   ALLOCATE HFS LIBRARY                                            *         
//*********************************************************************         
//*                                                                             
//ALLOCHFS PROC HLQ=,                                                           
//            DSP=,                                                             
//            HVOL=                                                             
//*                                                                             
//ALLOCH   EXEC PGM=IEFBR14                                                     
//*                                                                             
//SEEXHFS  DD DSN=&HLQ..SEEXHFS,                                                
//            DISP=(NEW,&DSP.),                                                 
//            UNIT=SYSALLDA,                                                    
//            VOL=SER=&HVOL,                                                    
//            SPACE=(CYL,(335,50,5)),                                           
//            DSNTYPE=HFS                                                       
//*                                                                             
//EALLOCH PEND                                                                  
//*                                                                             
//****************************************************************              
//*  The following steps execute the PROCs to allocate the data  *              
//*  sets from WebSphere Extended Deployment for z/OS 6.1.0      *              
//****************************************************************              
//*                                                                             
//ALLOCT EXEC ALLOCTGT,                                                         
//            HLQ=EEX,      * EEX is the default                                
//            DSP=CATLG,    * CATLG is the default                              
//            TVOL1=ttttt1  * No default; volume1 for target libraries          
//*                                                                             
//ALLOCD EXEC ALLOCDLB,                                                         
//            HLQ=EEX,      * EEX is the default                                
//            DSP=CATLG,    * CATLG is the default                              
//            DVOL=dddddd   * No default; volume for dist. libraries            
//*                                                                             
//****************************************************************              
//*   The following step executes the PROC to allocate a new     *              
//*   hfs data set for WebSphere Extended Deployment for z/OS    *              
//*   This is required if you are installing WebSphere Extended  *              
//*   Deployment for z/OS for the first time                     *              
//****************************************************************              
//*                                                                             
//ALLOCH EXEC ALLOCHFS,                                                         
//            HLQ=EEX,      * EEX is the default                                
//            DSP=CATLG,    * CATLG is the default                              
//            HVOL=hhhhhh   * No default; volume for HFS library                
//*                                                                             
