#!/bin/sh
#
# ================================================================ 
# PROPRIETARY-STATEMENT:                                           
# Licensed Material - Property of IBM                              
#                                                                  
# 5655-P28 (C) Copyright IBM Corp. 2006                            
# All Rights Reserved.                                             
# U.S. Government users - RESTRICTED RIGHTS - Use, Duplication, or 
# Disclosure restricted by GSA-ADP schedule contract with IBM Corp.
# Status = JECX610                                                 
# ================================================================ 
#
# create zos install image
# usage: ecxfinal.sh <configuration hfs location> <userid> <pswd>
#

if [ -z $1 ]
then
   echo "Syntax: ecxfinal.sh <config hfs> <userid> <pswd>"   
   echo "where userid and password are optional"
   exit 8
fi

ConfigRoot=$1

if [ ! -e $ConfigRoot/profiles/default/bin/setupCmdLine.sh ]
then
   echo "The Configuration HFS location specified is invalid. $ConfigRoot/profiles/default/bin/setupCmdLine.sh does not exist!"
   exit 8
fi

. $ConfigRoot/profiles/default/bin/setupCmdLine.sh

f=$($JAVA_HOME/bin/java -classpath $ConfigRoot/lib/configParsers.jar com.ibm.ws.config390.parsers.Find $ConfigRoot/profiles/default/config/cells/$WAS_CELL serverindex.xml serverType=\"DEPLOYMENT_MANAGER\")
echo ""
echo "extracting host from $f"
DmgrHost=$($JAVA_HOME/bin/java -classpath $ConfigRoot/lib/configParsers.jar com.ibm.ws.config390.parsers.ParseDmgrHostPort $f -host)
echo ""
echo "extracting port from $f"
DmgrPort=$($JAVA_HOME/bin/java -classpath $ConfigRoot/lib/configParsers.jar com.ibm.ws.config390.parsers.ParseDmgrHostPort $f -port)

echo ""
echo "DMGR Host= $DmgrHost, DMGR Port= $DmgrPort"
echo ""

if [ -z $DmgrHost ]
then
    echo "The DMGR Host was not extracted properly, please examine the error logs."
    exit 8
fi

if [ -z $DmgrPort ]
then
    echo "The DMGR Port was not extracted properly, please examine the error logs."
    exit 8
fi

FILENAME=/tmp/ecx.$WAS_CELL.$WAS_NODE.ports
if [ -e $FILENAME ]
then
	INPUT_LINE=`cat $FILENAME`
	XDAGENTPORT=`echo $INPUT_LINE | awk '{print $1}'`
	XDOVERLAYTCPPORT=`echo $INPUT_LINE | awk '{print $2}'`
	XDOVERLAYUDPPORT=`echo $INPUT_LINE | awk '{print $3}'` 
	echo "xdAgentPort is $XDAGENTPORT, xdOverlayTCPPort is $XDOVERLAYTCPPORT, xdOverlayUDPPort is $XDOVERLAYUDPPORT" 
fi

if [ $CONFIG_TYPE = DMGR ]
then
	if [ ! -e $FILENAME ]
	then
        	echo "No additional ports provided. No port updates required."
        else
		echo "Running DMGR wsadmin script"
		$ConfigRoot/bin/wsadmin.sh -conntype NONE -lang jython -f $ConfigRoot/bin/createXDAgentPorts.py $XDAGENTPORT $XDOVERLAYUDPPORT $XDOVERLAYTCPPORT 
	fi

	echo "Configuring the Deployment Manager"
	$ConfigRoot/profiles/default/bin/iscdeploy.sh -restore 
	rc=$?
	if [ rc -ne 0 ]
	then
		echo "iscdeploy.sh has failed!"
	fi
else
	if [ ! -e $FILENAME ]
	then
	       	echo "No additional ports provided. No port updates required."
        else
		if [ $# -eq 3 ]
		then
 			 echo "Running Node wsadmin script with admin security on"
	 		 $ConfigRoot/bin/wsadmin.sh -conntype SOAP -host $DmgrHost -port $DmgrPort -user $2 -password $3 -lang jython -f $ConfigRoot/bin/createXDAgentPorts.py $XDAGENTPORT $XDOVERLAYUDPPORT $XDOVERLAYTCPPORT 

 		elif [ $# -eq 1 ]	
		then
			echo "Running Node wsadmin script with no admin security"
 			 $ConfigRoot/bin/wsadmin.sh -conntype SOAP -host $DmgrHost -port $DmgrPort -lang jython -f $ConfigRoot/bin/createXDAgentPorts.py $XDAGENTPORT $XDOVERLAYUDPPORT $XDOVERLAYTCPPORT  
		else
			echo "Wrong number of parameters specified."
		fi
	fi

	echo "Configuring the AppServer Node"
	$ConfigRoot/profiles/default/bin/ecxsync.sh $ConfigRoot $2 $3
	rc=$?
	if [ rc -ne 0 ]
	then
		echo "ecxsync.sh has failed!"
	fi
fi
if [ -e $FILENAME ]
then
	rm $FILENAME
fi
exit rc
