#=======================================================================================================================================================
#(C) Copyright IBM Corp. 2007 - All Rights Reserved.
#DISCLAIMER:
#The following source code is sample code created by IBM Corporation.
#This sample code is provided to you solely for the purpose of assisting you
#in the  use of  the product. The code is provided 'AS IS', without warranty or
#condition of any kind. IBM shall not be liable for any damages arising out of your
#use of the sample code, even if IBM has been advised of the possibility of
#such damages.
#=======================================================================================================================================================

#=======================================================================================================================================================
# This file contains a series of operations to remove the Grid Execution Environemnet (GEE) application
#
# Change History
# --------------
# 30-10-07 initial version created
#=======================================================================================================================================================

import sys
lineSeparator  = java.lang.System.getProperty("line.separator")
fileSeparator  = java.lang.System.getProperty("file.separator")
wasInstallRoot = java.lang.System.getProperty("was.install.root")
osname         = java.lang.System.getProperty("os.name");


def printHelp():
  print """

  Show help:
      >> wsadmin -lang jython -f addCustomProperty.py --help
      
  Lists all grid endpoints:
      >> wsadmin -lang jython -f addCustomProperty.py --listEndpoints

  Adds all the JVM custom properties required by GEE to all grid endpoints:
      >> wsadmin -lang jython -f addCustomProperty.py 

  You may have to modify wsadmin to wsadmin.sh or wsadmin.bat, depending upon your operating environment.
  
  """
#  Add specified property to all Grid Endpoints:
#      >> wsadmin -lang jython -f addCustomProperty.py <property,value>

#      Example:
#      >> wsadmin -lang jython -f addCustomProperty.py com.ibm.ws.websphere.ejbcontainer,true
  
  
    


def getTargets():
    print "In getTargets.."
    targetList = []
    try:
        output = AdminApp.view("GEE", ["-MapModulesToServers"])
	print "output=" + output
        lines = output.split(lineSeparator)	
        for line in lines:
            server = line.split(":  ")	    
            if server[0] == "Server":
                targets = server[1].split("+")	 		
                for target in targets:
                    targetList.append(target[10:len(target)])
                break
    except:
        pass
        
    return targetList


def listTargets():

    print ""
    targets = getTargets()
    
    if len(targets) == 0:
        print "INFO: No Grid Execution Environment was found"
        return

    if len(targets) == 1:
        print "INFO: Grid Execution Environment was found on following target: "
        print "      " + targets[0]
        return
       
    print "INFO: Grid Execution Environment was found on following targets: "
    for target in targets:
         print "      " + target


def getClusterList():

    print ""
    print "In getClusterList..."
    targets = getTargets()
    
    clusterList = []
    for target in targets:
	servers = target.split(",")	
	for server in servers:
		type = server.split("=")
		if type[0] == "cluster":
		   clusterList.append(type[1])		
		   
    return clusterList
    
def getServerList():

    print ""
    print "In getServerList..."
    targets = getTargets()
    
    serverList = []
    for target in targets:
	servers = target.split(",")	
	sName = ""
	nName = ""
	for server in servers:
		type = server.split("=")
		if type[0] == "node":
		   nName = type[1]
		elif type[0] == "server":
		   sName = type[1]
	if sName != "":	   
		serverList.append((nName, sName))   		
		   
		   
    return serverList


def getDynamicClusterMembers (dynamicClusterName ):

   #---------------------------------------------------------------------------------
   # Get all dynamic cluster members for a given dynamic cluster name
   #---------------------------------------------------------------------------------

   endpointList = []

   clusterId = AdminConfig.getid("/ServerCluster:"+dynamicClusterName+"/")
   clusterMembers = AdminConfig. list("ClusterMember", clusterId).split(lineSeparator)
   for clusterMember in clusterMembers:      
      nodeName = AdminConfig.showAttribute(clusterMember, "nodeName")
      serverName = AdminConfig.showAttribute(clusterMember, "memberName")
      print "serverName =" + serverName
      endpointList.append((nodeName,serverName))
   #endFor

   return endpointList

#endDef

def addBatchCustomProperties(nodeName, serverName):
   print "serverName=" + serverName + " node=" + nodeName
   server = convertToList(AdminConfig.getid("/Node:"+nodeName+"/Server:"+serverName+"/"))[0]
   processDefs = convertToList(AdminConfig.showAttribute(server,"processDefinitions"))
   for processDef in processDefs:
      print "processDef =" + processDef
      jvmEntries = convertToList(AdminConfig.showAttribute(processDef,"jvmEntries"))
      for jvmEntry in jvmEntries:
	  print "jvmEntry=" + jvmEntry
          systemProperties = convertToList(AdminConfig.showAttribute(jvmEntry, "systemProperties"))
	  for property in systemProperties:
		print "property = "+ property
		if (property=="com.ibm.websphere.ejbcontainer.expandCMPCFJNDIName"):
			AdminConfig.remove(property)
		elif (property == "com.ibm.websphere.ejbcontainer.wlmAllowOptionAReadOnly"):
			AdminConfig.remove(property)	
	  AdminConfig.create("Property",jvmEntry,[["name","com.ibm.websphere.ejbcontainer.expandCMPCFJNDIName"],["value","true"]])
	  AdminConfig.create("Property",jvmEntry,[["name","com.ibm.websphere.ejbcontainer.wlmAllowOptionAReadOnly"],["value","true"]])
	  
	  
def convertToList(inlist):
     outlist=[]
     if (len(inlist)>0 and inlist[0]=='[' and inlist[len(inlist)-1]==']'):
        inlist = inlist[1:len(inlist)-1]
        clist = inlist.split("\"")
     else:
        clist = inlist.split("\n")
     for elem in clist:
        elem=elem.rstrip();
        if (len(elem)>0):
           outlist.append(elem)
     return outlist


    
def addProperties():

    print ""
    clusters = getClusterList()
    
    for cluster in clusters:
        print "clusterName=" + cluster
	endpointList = getDynamicClusterMembers(cluster)	
	for nName, sName in endpointList:
	      print "nName =" + nName + " sName=" + sName
	      addBatchCustomProperties(nName, sName)
	      
    servers = getServerList()
    for nName, sName in servers:
	print "nName ="+ nName + " sName=" + sName
	addBatchCustomProperties(nName, sName)
	 
		   
    
		
#=======================================================================================================================================================
#
# Main execution logic:
#
#=======================================================================================================================================================

if len(sys.argv) > 0:
    option = sys.argv[0]
    if option == "--help":
        printHelp()
    elif option == "--listEndpoints":
        sys.exit(listTargets())      
else:
    addProperties()
    print "saving workspace.."
    AdminConfig.save()