import sys
import java.lang.System  as  jsys

lineSeparator  = jsys.getProperty('line.separator')
fileSeparator  = jsys.getProperty('file.separator')

defaultAppName     = "ParallelJobManager"
defaultBackendName = "DERBY_V100_1"
defaultSchemaName  = "PJSCHEMA"
defaultJdbcName    = "jdbc/parallelJobManager"

scriptName         = "parallelJobManager.py"


#------------------------------------------------------------------------------
# Install the application
#------------------------------------------------------------------------------

def install(wasHome, cell, cluster, node, server, schema, backend, appname, jdbcName):

    ejbName     = defaultAppName + "EJBs"
    jarName     = ejbName + ".jar"
    xmlName     = jarName + ",META-INF/ejb-jar.xml"
    cellName    = "WebSphere:cell=" + cell
    systemApps  = "$(WAS_INSTALL_ROOT)" + fileSeparator + "systemApps"
    earPath     = wasHome + fileSeparator + "systemApps" + fileSeparator + defaultAppName + ".ear"
    pjmJob      = defaultAppName + "Job"

    if cluster != "":
        msg = "cluster " + cluster
        installTarget         = [ "-cluster", cluster ]
        MapModulesToServers   = [ [ ejbName, xmlName, cellName + ",cluster=" + cluster ] ]

    else:
        msg = "node/server " + node + "/" + server
        installTarget         = [ "-node", node, "-server", server ]
        MapModulesToServers   = [ [ ejbName, xmlName, cellName + ",node=" + node + ",server=" + server ] ]


    DataSourceFor20EJBModules = [ [ ejbName, xmlName, jdbcName ] ]

    DataSourceFor20CMPBeans   = [ 
                                  [ ejbName, "SubmittedJobs"     , xmlName, jdbcName, "cmpBinding.perConnectionFactory" ], 
                                  [ ejbName, "LogicalTX"         , xmlName, jdbcName, "cmpBinding.perConnectionFactory" ], 
                                  [ ejbName, "ParallelJobManager", xmlName, jdbcName, "cmpBinding.perConnectionFactory" ] 
                                ]

    BackendIdSelection        = [ [ ejbName, xmlName, backend ] ]

                                                                                                                                                                                                            
    MapEJBRefToEJB            = [                                                                                                                                                                           
                                  [ ejbName, "ParallelJobManagerJob", xmlName, "ejb/ParallelJobManager" , "com.ibm.websphere.batch.BatchJobStepLocalInterface", "ejb/com/ibm/ws/batch/ParallelJobManager"           ],
                                  [ ejbName, "ParallelJobManagerJob", xmlName, "ejb/SubmittedJobsAccess", "com.ibm.ws.batch.SubmittedJobsAccessLocal"         , "ejb/com/ibm/ws/batch/SubmittedJobsAccessLocalHome" ],
                                  [ ejbName, "ParallelJobManagerJob", xmlName, "ejb/SubmittedJobs"      , "com.ibm.ws.batch.SubmittedJobsLocal"               , "ejb/com/ibm/ws/batch/SubmittedJobsHome"            ],
                                  [ ejbName, "ParallelJobManagerJob", xmlName, "ejb/LogicalTXAccess"    , "com.ibm.ws.batch.LogicalTXAccessLocal"             , "ejb/com/ibm/ws/batch/LogicalTXAccessLocalHome"     ],
                                  [ ejbName, "ParallelJobManagerJob", xmlName, "ejb/LogicalTX"          , "com.ibm.ws.batch.LogicalTXLocal"                   , "ejb/com/ibm/ws/batch/LogicalTXHome"                ],
                                  [ ejbName, "SubmittedJobsAccess"  , xmlName, "ejb/SubmittedJobs"      , "com.ibm.ws.batch.SubmittedJobsLocal"               , "ejb/com/ibm/ws/batch/SubmittedJobsHome"            ],
                                  [ ejbName, "LogicalTXAccess"      , xmlName, "ejb/LogicalTX"          , "com.ibm.ws.batch.LogicalTXLocal"                   , "ejb/com/ibm/ws/batch/LogicalTXHome"                ],
                                  [ ejbName, "ParallelJobManager"   , xmlName, "ejb/SubmittedJobsAccess", "com.ibm.ws.batch.SubmittedJobsAccessLocal"         , "ejb/com/ibm/ws/batch/SubmittedJobsAccessLocalHome" ],
                                  [ ejbName, "ParallelJobManager"   , xmlName, "ejb/LogicalTXAccess"    , "com.ibm.ws.batch.LogicalTXAccessLocal"             , "ejb/com/ibm/ws/batch/LogicalTXAccessLocalHome"     ]
                                ]


    uninstall(cluster,appname)

    options = [ 
                "-nodeployejb",
                "-nopreCompileJSPs",
                "-distributeApp",
                "-createMBeansForResources",
                "-noreloadEnabled",
                "-deployws",
                "-noprocessEmbeddedConfig",
                "-usedefaultbindings",
                "-zeroEarCopy",

                installTarget,

                "-defaultbinding.datasource.jndi",  jdbcName,
                "-deployejb.dbschema",              schema,
                "-deployejb.dbtype",                backend,

                "-MapEJBRefToEJB",                  MapEJBRefToEJB,
                "-BackendIdSelection",              BackendIdSelection,
                "-MapModulesToServers",             MapModulesToServers,
                "-DataSourceFor20EJBModules",       DataSourceFor20EJBModules,
                "-DataSourceFor20CMPBeans",         DataSourceFor20CMPBeans,

                "-appname",                         appname, 
                "-installed.ear.destination",       systemApps
              ]

    AdminApp.install(earPath, options)

    save(cluster)

    startApplication(cell, cluster, node, server, appname)

    if appname != defaultAppName:
        msg = msg + " using application name " + appname

    print "INFO: installed " + defaultAppName + " to " + msg 


#------------------------------------------------------------------------------
# Start the application 
#------------------------------------------------------------------------------

def startApplication(cell, cluster, node, server, appname):

    if cluster != "":
        appManager = AdminControl.completeObjectName( "WebSphere:*,type=AppManagement,process=dmgr" )
        parameters = "[ " +  appname + " null null ]"
        signature = "[ java.lang.String java.util.Hashtable java.lang.String ]"
        AdminControl.invoke( appManager, 'startApplication', parameters, signature )
    else:
        appManager = AdminControl.queryNames( "cell=" + cell + ",node=" + node + ",type=ApplicationManager,process=" + server + ",*" )
        AdminControl.invoke( appManager, 'startApplication', appname )



#------------------------------------------------------------------------------
# Uninstall the ParallelJobManager
#------------------------------------------------------------------------------

def uninstall(cluster,appname):
    try: 
        AdminApp.uninstall(appname)
        result = "removed"
    except:
        result = ""

    if result == "removed":
        save(cluster)


#------------------------------------------------------------------------------
# Print script usage
#------------------------------------------------------------------------------

def usage(msg):
    print ""
    print scriptName + " : " + msg
    print ""
    print "Usage: wsadmin " + scriptName + " -install -cluster <clusterName>"
    print "  or:  wsadmin " + scriptName + " -install -node <nodeName> -server <serverName>"
    print "  or:  wsadmin " + scriptName + " -remove -cluster <clusterName>"
    print "  or:  wsadmin " + scriptName + " -remove -node <nodeName> -server <serverName>"
    print ""
    print "  -install is the default if -remove is not specified"
    print ""
    print "  either  -cluster  or  -node and -server  is required"
    print ""
    print "  the following options may be specified with -install"
    print "  -schema <schemaName> is optional and defaults to " + defaultSchemaName
    print "  -backend <dbType> is optional and defaults to "    + defaultBackendName
    print "  -jdbcname <jdbcname> is optional and defaults to " + defaultJdbcName
    print ""
    print "  the following option may be specified with -install and must be"
    print "    specified with -remove if not defaulted"
    print "  -appname <appname> is optional and defaults to "   + defaultAppName
    print ""
    sys.exit(101)

#------------------------------------------------------------------------------
# Save the configuration
#------------------------------------------------------------------------------
def save(cluster):
    AdminConfig.save()
    if cluster != "":
        dmgrbean = AdminControl.queryNames("type=DeploymentManager,*")
        AdminControl.invoke(dmgrbean, "syncActiveNodes", "true")
        msg = "Configuration was saved and synchronized to the active nodes"
    else:
        msg = "Configuration was saved"

    #print scriptName + " INFO: " + msg

#------------------------------------------------------------------------------
# Set the variable to the passed value if it has not already been set
#------------------------------------------------------------------------------
def setOpt(oldValue, newValue):
    if oldValue != "":
        usage( "duplicate option" )
    else:
        return newValue

#------------------------------------------------------------------------------
# Set the variable to the next arg value if it has not already been set
#------------------------------------------------------------------------------
def setArg(oldValue, argIndex):
    if oldValue != "":
        usage( "duplicate argument" )
    elif argIndex == len(sys.argv):
        usage( "missing value" )
    else:
        return sys.argv[argIndex]

#------------------------------------------------------------------------------
# Process the passed arguements
#------------------------------------------------------------------------------
def getArgs():
    actionType  = ""
    schemaName  = ""
    backendName = ""
    clusterName = ""
    nodeName    = ""
    serverName  = ""
    appName     = ""
    jdbcName    = ""

    i = 0

    while i < len(sys.argv):

        if sys.argv[i] == "-install":
            actionType = setOpt(actionType, "install")
        elif sys.argv[i] == "-remove":
            actionType = setOpt(actionType, "remove")
        elif sys.argv[i] == "-schema":
            i += 1
            schemaName = setArg(schemaName, i)
        elif sys.argv[i] == "-backend":
            i += 1
            backendName = setArg(backendName, i)
        elif sys.argv[i] == "-appname":
            i += 1
            appName = setArg(appName, i)
        elif sys.argv[i] == "-jdbcname":
            i += 1
            jdbcName = setArg(jdbcName, i)
        elif sys.argv[i] == "-cluster":
            i += 1
            clusterName = setArg(clusterName, i)
        elif sys.argv[i] == "-node":
            i += 1
            nodeName = setArg(nodeName, i)
        elif sys.argv[i] == "-server":
            i += 1
            serverName = setArg(serverName, i)
        else:
            usage( "unrecognized argument: " + sys.argv[i] )

        i += 1

    if actionType == "remove":
        if backendName != "":
            usage( "conflicting parameters: -backend with -remove" )
        elif schemaName != "":
            usage( "conflicting parameters: -schema with -remove" )
        elif jdbcName != "":
            usage( "conflicting parameters: -jdbcname with -remove" )

    if clusterName != "":
        if nodeName != "":
            usage( "either -cluster or -node and -server required" )
        elif serverName != "":
            usage( "either -cluster or -node and -server required" )
    elif nodeName == "":
        usage( "either -cluster or -node and -server required" )
    elif serverName == "":
        usage( "either -cluster or -node and -server required" )

    if actionType == "":
        actionType = "install"

    if backendName == "":
        backendName = defaultBackendName

    if schemaName == "":
        schemaName = defaultSchemaName

    if appName == "":
        appName = defaultAppName

    if jdbcName == "":
        jdbcName = defaultJdbcName

    return (actionType, schemaName, backendName, clusterName, nodeName, serverName, appName, jdbcName)

#------------------------------------------------------------------------------
# Get the directory, as a string, where WAS is installed.
#------------------------------------------------------------------------------
def getWASHome(cell, cluster, node):
    nodeName = node;
    if nodeName == "":
        topology = getCellNodeServer()
        nodeName = topology[1]
    varMap = AdminConfig.getid("/Cell:" + cell + "/Node:" + nodeName + "/VariableMap:/")
    entries = AdminConfig.list("VariableSubstitutionEntry", varMap)
    eList = entries.splitlines()
    for entry in eList:
        name =  AdminConfig.showAttribute(entry, "symbolicName")
        if name == "WAS_INSTALL_ROOT":
            value = AdminConfig.showAttribute(entry, "value")
            return value

    return java.lang.System.getenv('WAS_HOME')

#------------------------------------------------------------------------------
# Get a tuple containing the cell, node, server name, and type
#------------------------------------------------------------------------------
def getCellNodeServer():
    servers = AdminConfig.list("Server").splitlines()
    for serverId in servers:
        serverName = serverId.split("(")[0]
        server = serverId.split("(")[1]  #remove name( from id
        server = server.split("/")
        cell = server[1]
        node = server[3]
        cellId = AdminConfig.getid("/Cell:" + cell + "/")
        cellType = AdminConfig.showAttribute(cellId, "cellType")
        #print "cell: " + cell
        #print "node: " + node
        #print "cellId: " + cellId
        #print "cellType: " + cellType
        if cellType == "DISTRIBUTED":
            if AdminConfig.showAttribute(serverId, "serverType") == "DEPLOYMENT_MANAGER":
                return (cell, node, serverName, "DEPLOYMENT_MANAGER") 
        elif cellType == "STANDALONE":
            if AdminConfig.showAttribute(serverId, "serverType") == "APPLICATION_SERVER":
                return (cell, node, serverName, "APPLICATION_SERVER") 
    return None	

#------------------------------------------------------------------------------
# Main entry point
#------------------------------------------------------------------------------

failOnError = "false" 

if len(sys.argv) < 1 or len(sys.argv) > 13:
	usage( "too many or too few arguments" )

args = getArgs()

action   = args[0]
schema   = args[1]
backend  = args[2]
cluster  = args[3]
node     = args[4]
server   = args[5]
appname  = args[6]
jdbcname = args[7]

if action == "install":
    print ""
    print "appname:  " + appname
    print "schema:   " + schema
    print "backend:  " + backend
    print "jdbcname: " + jdbcname
    if cluster != "":
        print "cluster:  " + cluster
    else:
        print "node:     " + node
        print "server:   " + server
    print ""

cell = AdminControl.getCell()
wasHome = getWASHome(cell,cluster,node)


if action == "install":
    install(wasHome,cell,cluster,node,server,schema,backend,appname,jdbcname)
else:
    uninstall(cluster,appname)

