-- This script creates Long Running Scheduler tables on a db2 instance.
-- The default name of the database is LRSCHED, default schema name is
-- LRSSCHEMA and default tablesapce is USERSPACE1. All these defaults
-- can be replaced with different names if needed.
-- The following commands can be issue from DB2 command line processor
-- to run this script:
--             db2 -tf CreateLRSCHEDTablesDB2.ddl



 
CONNECT TO LRSCHED;



CREATE SCHEMA LRSSCHEMA;

------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT"  (

		  "JOBSCHEDULERNAME" VARCHAR(250) NOT NULL , 

		  "JOBNUMBER" INTEGER NOT NULL,
		  
		  "JOBCREATETIME" VARCHAR(23) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT"



ALTER TABLE "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT" 

	ADD CONSTRAINT "PK_GLOBALJOBIDASS2" PRIMARY KEY

		("JOBNUMBER");







------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."LOGMESSAGES"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."LOGMESSAGES"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "MSGSEQ" INTEGER NOT NULL , 

		  "MSGTXT" VARCHAR(250) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."LOGMESSAGES"



ALTER TABLE "LRSSCHEMA"."LOGMESSAGES" 

	ADD CONSTRAINT "PK_LOGMESSAGES" PRIMARY KEY

		("JOBID",

		 "MSGSEQ");







------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."JOBSTATUS"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."JOBSTATUS"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "STATUS" INTEGER NOT NULL , 

		  "RC" INTEGER NOT NULL , 

		  "UPDATECNT" INTEGER NOT NULL , 

		  "LASTUPDATE" VARCHAR(250) , 

		  "SUSPENDEDUNTIL" VARCHAR(250) , 

		  "SCHEDULEROWNS" SMALLINT NOT NULL , 

		  "OWNINGBJEE" VARCHAR(250) , 

		  "TYPE" VARCHAR(16),

		  "SUBMITTER" VARCHAR(256),

		  "NODE" VARCHAR(250),

		  "APPSERVER" VARCHAR(250),

		  "STATUSTXT" VARCHAR(250), 
		  
		  "STARTTIME" VARCHAR(250),
		  
		  "REQUESTID" VARCHAR(250),
		  
		  "LOGCURRENTPART" VARCHAR(250) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBSTATUS"



ALTER TABLE "LRSSCHEMA"."JOBSTATUS" 

	ADD CONSTRAINT "PK_JOBSTATUS" PRIMARY KEY

		("JOBID");







------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."SCHEDULERCOUNTER"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."SCHEDULERCOUNTER"  (

		  "CNTNAME" VARCHAR(250) NOT NULL , 

		  "CNT" INTEGER NOT NULL )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."SCHEDULERCOUNTER"



ALTER TABLE "LRSSCHEMA"."SCHEDULERCOUNTER" 

	ADD CONSTRAINT "PK_SCHEDULERCOUNT3" PRIMARY KEY

		("CNTNAME");






------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."XJCLREPOSITORY"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."XJCLREPOSITORY"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "SEQ" INTEGER NOT NULL , 

		  "TXT" VARCHAR(250) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."XJCLREPOSITORY"



ALTER TABLE "LRSSCHEMA"."XJCLREPOSITORY" 

	ADD CONSTRAINT "PK_XJCLREPOSITORY" PRIMARY KEY

		("JOBID",

		 "SEQ");








------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."JOBREPOSITORY"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."JOBREPOSITORY"  (

		  "JOBNAME" VARCHAR(250) NOT NULL , 

		  "SEQ" INTEGER NOT NULL , 

		  "TXT" VARCHAR(250) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBREPOSITORY"



ALTER TABLE "LRSSCHEMA"."JOBREPOSITORY" 

	ADD CONSTRAINT "PK_JOBREPOSITORY" PRIMARY KEY

		("JOBNAME",
                
		 "SEQ");


------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."RECURRINGREQUEST"

------------------------------------------------


-- Maximum length of NAMEVALUEPAIRS (in bytes) : 2682
-- source: http://publib.boulder.ibm.com/infocenter/db2luw/v8/index.jsp

 

 CREATE TABLE "LRSSCHEMA"."RECURRINGREQUEST"  (

		  "REQUESTID" VARCHAR(250) NOT NULL , 

		  "JOBNAME" VARCHAR(250) NOT NULL , 

		  "STARTTIME" VARCHAR(250) NOT NULL , 

		  "INTERVAL" VARCHAR(250) NOT NULL , 
		  
		  "NAMEVALUEPAIRS" VARCHAR(2458) NOT NULL ,
		  
		  "SUBMITTER" VARCHAR(256),

		  "STATUS" INTEGER, 

		  "FIELD1" INTEGER, 

		  "FIELD2" VARCHAR(250) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."RECURRINGREQUEST"



ALTER TABLE "LRSSCHEMA"."RECURRINGREQUEST" 

	ADD CONSTRAINT "PK_RECURRINGREQ" PRIMARY KEY

		("REQUESTID");




------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."JMCUSERPREF"

------------------------------------------------

 CREATE TABLE "LRSSCHEMA"."JMCUSERPREF"  (

		  "USERID" VARCHAR(32) NOT NULL , 
		  
		  "PREFSCOPE" VARCHAR(32) NOT NULL,

		  "PREFNAME" VARCHAR(64) NOT NULL, 

		  "PREFVALUE" VARCHAR(255) NOT NULL )

		 IN "USERSPACE1" ;  


-- DDL Statements for primary key on Table "LRSSCHEMA"."JMCUSERPREF"

ALTER TABLE "LRSSCHEMA"."JMCUSERPREF" 

	ADD CONSTRAINT "PK_JMCUSERPREF" PRIMARY KEY

		("USERID",
		
		 "PREFSCOPE",
		
		 "PREFNAME");



------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBPROFILE"
------------------------------------------------

 CREATE TABLE "LRSSCHEMA"."JOBPROFILE"  (

		  "JOBCLASS" VARCHAR(250) NOT NULL , 
		  
		  "MEANWORK" DOUBLE NOT NULL,

          "MEANSQUAREWORK" DOUBLE NOT NULL, 

          "MEANCUBEWORK" DOUBLE NOT NULL, 

          "MINWORK" DOUBLE NOT NULL, 

          "MAXWORK" DOUBLE NOT NULL, 

          "NUMJOBSAMPLES" DOUBLE NOT NULL, 

          "CONCURRENCYLEVEL" DOUBLE NOT NULL, 

          "MEMORY" DOUBLE NOT NULL, 

		  "LASTUPDATE" VARCHAR(64) NOT NULL)
		  
		  IN "USERSPACE1" ;  



-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBPROFILE"
-----------------------------------------------------------------------
ALTER TABLE "LRSSCHEMA"."JOBPROFILE"

	ADD CONSTRAINT "PK_JOBPROFILE" PRIMARY KEY
	
		("JOBCLASS");	



------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBUSAGE"
------------------------------------------------

 CREATE TABLE "LRSSCHEMA"."JOBUSAGE"  (

		  "JOBID" VARCHAR(250) NOT NULL , 
		  
		  "SUBMITTER" VARCHAR(256),

          "CPUCONSUMEDSOFAR" BIGINT NOT NULL, 
          
          "JOBSTATE" VARCHAR(32) NOT NULL,

          "SERVER" VARCHAR(250) NOT NULL, 

          "NODE" VARCHAR(250) NOT NULL, 

          "STARTTIME" VARCHAR(64) NOT NULL, 

          "LASTUPDATE" VARCHAR(64) NOT NULL, 

          "ACCNTING" CHAR(64) ) 

		IN "USERSPACE1" ;  



-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBUSAGE"
-----------------------------------------------------------------------
ALTER TABLE "LRSSCHEMA"."JOBUSAGE"
	
	ADD CONSTRAINT "PK_JOBUSAGE" PRIMARY KEY
	
	("JOBID","STARTTIME");	
		

------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."JOBCLASSMAXCONCJOBS"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."JOBCLASSMAXCONCJOBS"  (

		  "JOBCLASSNAME" VARCHAR(250) NOT NULL , 

		  "CONCJOBCOUNT" INTEGER NOT NULL )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBCLASSMAXCONCJOBS"



ALTER TABLE "LRSSCHEMA"."JOBCLASSMAXCONCJOBS" 

	ADD CONSTRAINT "PK_JOBCLSMAXCJOBS" PRIMARY KEY

		("JOBCLASSNAME");

------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."JOBCLASSEXEREC"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."JOBCLASSEXEREC"  (

		  "JOBCLASSNAME" VARCHAR(250) NOT NULL , 

		  "LASTUPDATE" VARCHAR(250) NOT NULL,
		  
		  "JOBID" VARCHAR(250) NOT NULL )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBCLASSEXEREC"



ALTER TABLE "LRSSCHEMA"."JOBCLASSEXEREC" 

	ADD CONSTRAINT "PK_JOBCLASSEXEREC" PRIMARY KEY

		("JOBID");



------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."JOBIDCONTROL"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."JOBIDCONTROL"  (

		  "CONTROLNAME" VARCHAR(250) NOT NULL , 

		  "CONTROLVALUE" INTEGER NOT NULL )   

		   ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBIDCONTROL"



ALTER TABLE "LRSSCHEMA"."JOBIDCONTROL" 

	ADD CONSTRAINT "PK_JOBIDCONTROL" PRIMARY KEY

		("CONTROLNAME");



------------------------------------------------

-- DDL Statements for table "LRSSCHEMA"."JOBREDOLIST"

------------------------------------------------

 

 CREATE TABLE "LRSSCHEMA"."JOBREDOLIST"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "EENAME" VARCHAR(250) NOT NULL , 

		  "ACTION" VARCHAR(32) NOT NULL )   

		   ; 



-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBREDOLIST"



ALTER TABLE "LRSSCHEMA"."JOBREDOLIST" 

	ADD CONSTRAINT "PK_JOBREDOLIST" PRIMARY KEY

		("JOBID", "EENAME");
		
		
		
		
COMMIT WORK;



CONNECT RESET;



TERMINATE;

-- Specified SCHEMA is: LRSSCHEMA

-- Creating DDL for table(s)



-- Schema name is ignored for the Federated Section

-- Binding package automatically ... 

-- Bind is successful

-- Binding package automatically ... 

-- Bind is successful

;
