-- This script creates Long Running Execution Environment tables on a Informix instance.
-- The default name of the database is LRSCHED, default schema name is
-- LRSSSCHEMA and default tablespace is rootdbs. All these defaults
-- can be replaced with different names if needed.
-- The following command can be issued from Informix command line processor.
-- To run this script type at cmd-line in <informix_install>/bin
-- dbaccess - CreateLrschedTablesInformix.sql



CONNECT TO "LRSCHED";

-- BEGIN WORK;

---------------------------------------
--DDL statements for schema: "LRSSCHEMA
---------------------------------------
CREATE SCHEMA AUTHORIZATION LRSSCHEMA;



------------------------------------------------------------
--DDL statements for table: "LRSSCHEMA.GLOBALJOBIDASSIGNMENT
------------------------------------------------------------
CREATE TABLE LRSSCHEMA.GLOBALJOBIDASSIGNMENT (

		  JOBSCHEDULERNAME VARCHAR(250) NOT NULL , 

		  JOBNUMBER INTEGER NOT NULL,
		  
		  JOBCREATETIME VARCHAR(23)
                  )
                  IN rootdbs;  

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.GLOBALJOBIDASSIGNMENT"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.GLOBALJOBIDASSIGNMENT
      ADD CONSTRAINT PRIMARY KEY(JOBNUMBER) CONSTRAINT PK_GLOBALJOBIDASS2;






--------------------------------------------------
--DDL statements for table: "LRSSCHEMA.LOGMESSAGES
--------------------------------------------------		
CREATE TABLE LRSSCHEMA.LOGMESSAGES  (

		  JOBID VARCHAR(130) NOT NULL , 

		  MSGSEQ INTEGER NOT NULL , 

		  MSGTXT VARCHAR(250)  
                  
                  )
                  IN rootdbs;
-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.LOGMESSAGES"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.LOGMESSAGES
      ADD CONSTRAINT PRIMARY KEY(JOBID,MSGSEQ) CONSTRAINT PK_LOGMESSAGES;




------------------------------------------------
--DDL statements for table: "LRSSCHEMA.JOBSTATUS
------------------------------------------------	
CREATE TABLE LRSSCHEMA.JOBSTATUS  (

		  JOBID VARCHAR(130) NOT NULL , 

		  STATUS INTEGER NOT NULL , 

		  RC INTEGER NOT NULL , 

		  UPDATECNT INTEGER NOT NULL , 

		  LASTUPDATE VARCHAR(250) , 

		  SUSPENDEDUNTIL VARCHAR(250) , 

		  SCHEDULEROWNS SMALLINT NOT NULL , 

		  OWNINGBJEE VARCHAR(250) , 

		  TYPE VARCHAR(16),

		  SUBMITTER VARCHAR(256),

		  NODE VARCHAR(250),

		  APPSERVER VARCHAR(250),

		  STATUSTXT VARCHAR(250),

        STARTTIME VARCHAR(250),

        REQUESTID VARCHAR(250),

        LOGCURRENTPART VARCHAR(250)
                  )
                  IN rootdbs;  

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.JOBSTATUS"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBSTATUS
      ADD CONSTRAINT PRIMARY KEY(JOBID) CONSTRAINT PK_JOBSTATUS;




-------------------------------------------------------
--DDL statements for table: "LRSSCHEMA.SCHEDULERCOUNTER
-------------------------------------------------------
CREATE TABLE LRSSCHEMA.SCHEDULERCOUNTER  (

		  CNTNAME VARCHAR(250) NOT NULL , 

		  CNT INTEGER NOT NULL
                  )
                  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.SCHEDULERCOUNTER"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.SCHEDULERCOUNTER
      ADD CONSTRAINT PRIMARY KEY(CNTNAME) CONSTRAINT PK_SCHEDULERCOUNTS;




-----------------------------------------------------
--DDL ststements for table: "LRSSCHEMA.XJCLREPOSITORY
-----------------------------------------------------
CREATE TABLE LRSSCHEMA.XJCLREPOSITORY (

		  JOBID VARCHAR(130) NOT NULL , 

		  SEQ INTEGER NOT NULL , 

		  TXT VARCHAR(250)
                  )
                  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.XJCLREPOSITORY"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.XJCLREPOSITORY
      ADD CONSTRAINT PRIMARY KEY(JOBID,SEQ) CONSTRAINT PK_XJCLRESPOSITORY;



 
----------------------------------------------------
--DDL statements for table: "LRSSCHEMA.JOBREPOSITORY
----------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBREPOSITORY  (

		  JOBNAME VARCHAR(250) NOT NULL , 

		  SEQ INTEGER NOT NULL , 

		  TXT VARCHAR(250)
                  )
                  IN rootdbs; 

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.JOBREPOSITORY"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBREPOSITORY
      ADD CONSTRAINT PRIMARY KEY(JOBNAME,SEQ) CONSTRAINT PK_JOBRESPOSITORYY;



--------------------------------------------------------------------
--DDL statements for table "LRSSCHEMA.RECURRINGREQUEST"
--------------------------------------------------------------------
CREATE TABLE LRSSCHEMA.RECURRINGREQUEST  (

		  REQUESTID VARCHAR(250) NOT NULL , 

		  JOBNAME VARCHAR(250) NOT NULL , 
                  
                  STARTTIME VARCHAR(250) NOT NULL,
 
                  INTERVAL VARCHAR(250) NOT NULL,
          
                  NAMEVALUEPAIRS VARCHAR(255) NOT NULL,
      
                  SUBMITTER VARCHAR(256),

                  STATUS INTEGER,

                  FIELD1 INTEGER,

                  FIELD2 VARCHAR(250)

		  )
                  IN rootdbs; 

-----------------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.RECURRINGREQUEST"
-----------------------------------------------------------------------
ALTER TABLE LRSSCHEMA.RECURRINGREQUEST
      ADD CONSTRAINT PRIMARY KEY(REQUESTID) CONSTRAINT PK_RECURRINGREQUEST;
                 

------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JMCUSERPREF"
------------------------------------------------

 CREATE TABLE LRSSCHEMA.JMCUSERPREF  (

		  USERID VARCHAR(32) NOT NULL , 
		  
		  PREFSCOPE VARCHAR(32) NOT NULL,

		  PREFNAME VARCHAR(64) NOT NULL, 

		  PREFVALUE VARCHAR(255) NOT NULL    

		 )
                  IN rootdbs;  

-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JMCUSERPREF"
-----------------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JMCUSERPREF
	ADD CONSTRAINT PRIMARY KEY(USERID,PREFSCOPE,PREFNAME) CONSTRAINT PK_JMCUSERPREF;


------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBPROFILE"
------------------------------------------------

 CREATE TABLE LRSSCHEMA.JOBPROFILE  (

		  JOBCLASS VARCHAR(250) NOT NULL , 
		  
		  MEANWORK FLOAT NOT NULL,

          MEANSQUAREWORK FLOAT NOT NULL, 

          MEANCUBEWORK FLOAT NOT NULL, 

          MINWORK FLOAT NOT NULL, 

          MAXWORK FLOAT NOT NULL, 

          NUMJOBSAMPLES FLOAT NOT NULL, 

          CONCURRENCYLEVEL FLOAT NOT NULL, 

          MEMORY FLOAT NOT NULL, 

		  LASTUPDATE VARCHAR(64) NOT NULL    

		 )
                  IN rootdbs;  

-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBPROFILEF"
-----------------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBPROFILE
	ADD CONSTRAINT PRIMARY KEY(JOBCLASS) CONSTRAINT PK_JOBPROFILE;	


------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBUSAGE"
------------------------------------------------

 CREATE TABLE LRSSCHEMA.JOBUSAGE  (

		  JOBID VARCHAR(250) NOT NULL , 
		  
		  SUBMITTER VARCHAR(256),

          CPUCONSUMEDSOFAR INT8 NOT NULL, 
          
          JOBSTATE VARCHAR(32) NOT NULL,

          SERVER VARCHAR(250) NOT NULL, 

          NODE VARCHAR(250) NOT NULL, 

          STARTTIME VARCHAR(64) NOT NULL, 

          LASTUPDATE VARCHAR(64) NOT NULL, 

          ACCNTING CHAR(64) 

		 )
                  IN rootdbs;  

-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBUSAGE"
-----------------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBUSAGE
	ADD CONSTRAINT PRIMARY KEY(JOBID,STARTTIME) CONSTRAINT PK_JOBUSAGE;	
	
------------------------------------------------------------
--DDL statements for table: "LRSSCHEMA.JOBCLASSMAXCONCJOBS
-------------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBCLASSMAXCONCJOBS  (

		  JOBCLASSNAME VARCHAR(250) NOT NULL , 

		  CONCJOBCOUNT INTEGER NOT NULL
                  )
                  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.JOBCLASSMAXCONCJOBS"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBCLASSMAXCONCJOBS
      ADD CONSTRAINT PRIMARY KEY(JOBCLASSNAME) CONSTRAINT PK_JOBCLSMAXCJOBS;


      
------------------------------------------------------------
--DDL statements for table: "LRSSCHEMA.JOBCLASSEXEREC"
-------------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBCLASSEXEREC  (

		  JOBCLASSNAME VARCHAR(250) NOT NULL , 

		  LASTUPDATE VARCHAR(250) NOT NULL,
		  
		  JOBID VARCHAR(250) NOT NULL		  
                  )
                  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.JOBCLASSEXEREC"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBCLASSEXEREC
      ADD CONSTRAINT PRIMARY KEY(JOBID) CONSTRAINT PK_JOBCLASSEXEREC;

            
                 
------------------------------------------------
-- DDL Statements for table "LRSSCHEMA.JOBIDCONTROL"
------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBIDCONTROL  (

		  CONTROLNAME VARCHAR(250) NOT NULL , 

		  CONTROLVALUE INTEGER NOT NULL
		  
		  )   

		  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA.JOBIDCONTROL"
-------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBIDCONTROL 
	ADD CONSTRAINT PRIMARY KEY(CONTROLNAME) CONSTRAINT  PK_JOBIDCONTROL;



------------------------------------------------
-- DDL Statements for table "LRSSCHEMA.JOBREDOLIST"
------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBREDOLIST  (

		  JOBID VARCHAR(250) NOT NULL , 

		  EENAME VARCHAR(250) NOT NULL , 

		  ACTION VARCHAR(32) NOT NULL

		  )   

		  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA.JOBREDOLIST"
-------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBREDOLIST 
	ADD CONSTRAINT PRIMARY KEY (JOBID, EENAME) CONSTRAINT PK_JOBREDOLIST;
		
		
			
			 
-- COMMIT WORK;

