-- This script creates Long Running Scheduler tables on an oracle db.
--
-- 1.Process this script using SQL*Plus
-- 2. Replace all occurrances of @LRSCHED_TABLESPACE@ with a valid tablespace that was 
--    created by the CreateLRSCHEDTablespaceOracle.ddl script.
-- Example: 
--  o  sqlplus username/password@LRSCHED @CreateLRSCHEDTablesOracle.ddl
--  o  or, at the sqlplus prompt, enter
--     SQL> @CreateLRSCHEDTablesOracle.ddl


------------------------------------------------

-- DDL Statements for table "GLOBALJOBIDASSIGNMENT"

------------------------------------------------

 

 CREATE TABLE "GLOBALJOBIDASSIGNMENT"  (
		  "JOBSCHEDULERNAME" VARCHAR(250) NOT NULL , 
		  "JOBNUMBER" INTEGER NOT NULL,
		  "JOBCREATETIME" VARCHAR(23) )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "GLOBALJOBIDASSIGNMENT"



ALTER TABLE "GLOBALJOBIDASSIGNMENT" 
	ADD CONSTRAINT "PK_GLOBALJOBIDASS2" PRIMARY KEY
		("JOBNUMBER");






------------------------------------------------

-- DDL Statements for table "LOGMESSAGES"

------------------------------------------------

 

 CREATE TABLE "LOGMESSAGES"  (
		  "JOBID" VARCHAR(250) NOT NULL , 
		  "MSGSEQ" INTEGER NOT NULL , 
		  "MSGTXT" VARCHAR(250) )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "LOGMESSAGES"



ALTER TABLE "LOGMESSAGES" 
	ADD CONSTRAINT "PK_LOGMESSAGES" PRIMARY KEY
		("JOBID",
		 "MSGSEQ");







------------------------------------------------

-- DDL Statements for table "JOBSTATUS"

------------------------------------------------

 

 CREATE TABLE "JOBSTATUS"  (
		  "JOBID" VARCHAR(250) NOT NULL , 
		  "STATUS" INTEGER NOT NULL , 
		  "RC" INTEGER NOT NULL , 
		  "UPDATECNT" INTEGER NOT NULL , 
		  "LASTUPDATE" VARCHAR(250) , 
		  "SUSPENDEDUNTIL" VARCHAR(250) , 
		  "SCHEDULEROWNS" SMALLINT NOT NULL , 
		  "OWNINGBJEE" VARCHAR(250) , 
		  "TYPE" VARCHAR(16),
		  "SUBMITTER" VARCHAR(256),
		  "NODE" VARCHAR(250),
		  "APPSERVER" VARCHAR(250),
		  "STATUSTXT" VARCHAR(250),
		  "STARTTIME" VARCHAR(250),
		  "REQUESTID" VARCHAR(250),
		  "LOGCURRENTPART" VARCHAR(250) )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBSTATUS"



ALTER TABLE "JOBSTATUS" 
	ADD CONSTRAINT "PK_JOBSTATUS" PRIMARY KEY
		("JOBID");







------------------------------------------------

-- DDL Statements for table "SCHEDULERCOUNTER"

------------------------------------------------

 

 CREATE TABLE "SCHEDULERCOUNTER"  (
		  "CNTNAME" VARCHAR(250) NOT NULL , 
		  "CNT" INTEGER NOT NULL )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "SCHEDULERCOUNTER"



ALTER TABLE "SCHEDULERCOUNTER" 
	ADD CONSTRAINT "PK_SCHEDULERCOUNT3" PRIMARY KEY
		("CNTNAME");







------------------------------------------------

-- DDL Statements for table "XJCLREPOSITORY"

------------------------------------------------

 

 CREATE TABLE "XJCLREPOSITORY"  (
		  "JOBID" VARCHAR(250) NOT NULL , 
		  "SEQ" INTEGER NOT NULL , 
		  "TXT" VARCHAR(250) )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "XJCLREPOSITORY"



ALTER TABLE "XJCLREPOSITORY" 
	ADD CONSTRAINT "PK_XJCLREPOSITORY" PRIMARY KEY
		("JOBID",
		 "SEQ");






------------------------------------------------

-- DDL Statements for table "JOBREPOSITORY"

------------------------------------------------

 

 CREATE TABLE "JOBREPOSITORY"  (
		  "JOBNAME" VARCHAR(250) NOT NULL , 
		  "SEQ" INTEGER NOT NULL , 
		  "TXT" VARCHAR(250) )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBREPOSITORY"



ALTER TABLE "JOBREPOSITORY" 
	ADD CONSTRAINT "PK_JOBREPOSITORY" PRIMARY KEY
		("JOBNAME",
		 "SEQ");

		 
		 
		 
		 
------------------------------------------------

-- DDL Statements for table "RECURRINGREQUEST"

------------------------------------------------

 

 CREATE TABLE "RECURRINGREQUEST"  (
		  "REQUESTID" VARCHAR(250) NOT NULL , 
		  "JOBNAME" VARCHAR(250) NOT NULL , 
		  "STARTTIME" VARCHAR(250) NOT NULL , 
		  "INTERVAL" VARCHAR(250) NOT NULL ,
		  "NAMEVALUEPAIRS" VARCHAR(2682) NOT NULL ,
		  "SUBMITTER" VARCHAR(256),
		  "STATUS" INTEGER, 
		  "FIELD1" INTEGER, 
		  "FIELD2" VARCHAR(250) )   
		  TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "RECURRINGREQUEST"



ALTER TABLE "RECURRINGREQUEST" 
	ADD CONSTRAINT "PK_RECURRINGREQ" PRIMARY KEY
		("REQUESTID");



------------------------------------------------

-- DDL Statements for table "JMCUSERPREF"

------------------------------------------------

 CREATE TABLE "JMCUSERPREF"  (
		  "USERID" VARCHAR(32) NOT NULL , 
		  "PREFSCOPE" VARCHAR(32) NOT NULL,
		  "PREFNAME" VARCHAR(64) NOT NULL, 
		  "PREFVALUE" VARCHAR(255) NOT NULL )   
		  TABLESPACE @LRSCHED_TABLESPACE@ ; 


-- DDL Statements for primary key on Table "JMCUSERPREF"

ALTER TABLE "JMCUSERPREF" 
	ADD CONSTRAINT "PK_JMCUSERPREF" PRIMARY KEY
		("USERID","PREFSCOPE","PREFNAME");
		
		
		
------------------------------------------------

-- DDL Statements for table "JOBPROFILE"

------------------------------------------------

 CREATE TABLE "JOBPROFILE"  (
		  "JOBCLASS" VARCHAR(32) NOT NULL , 
		  "MEANWORK" DOUBLE PRECISION NOT NULL,
		  "MEANSQUAREWORK" DOUBLE PRECISION NOT NULL, 
		  "MEANCUBEWORK" DOUBLE PRECISION NOT NULL,		   
		  "MINWORK" DOUBLE PRECISION NOT NULL, 
		  "MAXWORK" DOUBLE PRECISION NOT NULL,
		  "NUMJOBSAMPLES" DOUBLE PRECISION NOT NULL, 
		  "CONCURRENCYLEVEL" DOUBLE PRECISION NOT NULL, 
		  "MEMORY" DOUBLE PRECISION NOT NULL, 
		  "LASTUPDATE" VARCHAR(64) NOT NULL )   
		  TABLESPACE @LRSCHED_TABLESPACE@ ; 


-- DDL Statements for primary key on Table "JOBPROFILE"

ALTER TABLE "JOBPROFILE" 
	ADD CONSTRAINT "PK_JOBPROFILE" PRIMARY KEY
		("JOBCLASS");

------------------------------------------------

-- DDL Statements for table "JOBUSAGE"

------------------------------------------------

 CREATE TABLE "JOBUSAGE"  (
		  "JOBID" VARCHAR(250) NOT NULL, 
		  "SUBMITTER" VARCHAR(256),
		  "CPUCONSUMEDSOFAR" NUMBER NOT NULL, 
		  "JOBSTATE" VARCHAR(32) NOT NULL,		   
		  "SERVER" VARCHAR(250) NOT NULL, 
		  "NODE" VARCHAR(250) NOT NULL, 
		  "STARTTIME" VARCHAR(64) NOT NULL, 
		  "LASTUPDATE" VARCHAR(64) NOT NULL, 
		  "ACCNTING" CHAR(64))   
		  TABLESPACE @LRSCHED_TABLESPACE@ ; 


-- DDL Statements for primary key on Table "JOBUSAGE"

ALTER TABLE "JOBUSAGE" 
	ADD CONSTRAINT "PK_JOBUSAGE" PRIMARY KEY
		("JOBID","STARTTIME");
				

------------------------------------------------

-- DDL Statements for table "JOBCLASSMAXCONCJOBS"

------------------------------------------------

 

 CREATE TABLE "JOBCLASSMAXCONCJOBS"  (
		  "JOBCLASSNAME" VARCHAR(250) NOT NULL , 
		  "CONCJOBCOUNT" INTEGER NOT NULL )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBCLASSMAXCONCJOBS"



ALTER TABLE "JOBCLASSMAXCONCJOBS" 
	ADD CONSTRAINT "PK_JOBCLSMAXCJOBS" PRIMARY KEY
		("JOBCLASSNAME");

------------------------------------------------

-- DDL Statements for table "JOBCLASSEXEREC"

------------------------------------------------

 

 CREATE TABLE "JOBCLASSEXEREC"  (
		  "JOBCLASSNAME" VARCHAR(250) NOT NULL , 
		  "LASTUPDATE" VARCHAR(250) NOT NULL,
		  "JOBID" VARCHAR(250) NOT NULL )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBCLASSEXEREC"



ALTER TABLE "JOBCLASSEXEREC" 
	ADD CONSTRAINT "PK_JOBCLASSEXEREC" PRIMARY KEY
		("JOBID");

		 
------------------------------------------------

-- DDL Statements for table "JOBIDCONTROL"

------------------------------------------------

 

 CREATE TABLE "JOBIDCONTROL"  (
		  "CONTROLNAME" VARCHAR(250) NOT NULL , 
		  "CONTROLVALUE" INTEGER NOT NULL )   
          TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBIDCONTROL"



ALTER TABLE "JOBIDCONTROL" 
	ADD CONSTRAINT "PK_JOBIDCONTROL" PRIMARY KEY
		("CONTROLNAME");



------------------------------------------------

-- DDL Statements for table "JOBREDOLIST"

------------------------------------------------

 

CREATE TABLE "JOBREDOLIST"  (
		 "JOBID" VARCHAR(250) NOT NULL , 
		 "EENAME" VARCHAR(250) NOT NULL , 
		 "ACTION" VARCHAR(32) NOT NULL )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 




-- DDL Statements for primary key on Table "JOBREDOLIST"



ALTER TABLE "JOBREDOLIST" 
	ADD CONSTRAINT "PK_JOBREDOLIST" PRIMARY KEY
		("JOBID", "EENAME");