-- This script migrates XD 6.0.2 Long Running Scheduler tables to XD 6.1 on a db2 instance.
-- This script can be modified if needed to change the name of database or name of the Schema used. 
-- Default database name is LRSCHED and default schema name is LRSSCHEMA.
-- The following commands can be issue from DB2 command line processor
-- to run this script:
--             db2 -tf MigrateLRSCHEDTablesDB2.ddl

CONNECT TO LRSCHED;

-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT"
-----------------------------------------------------------------------

ALTER TABLE "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT" 
	ADD "JOBCREATETIME" VARCHAR(23)
	;

ALTER TABLE "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT" 
    DROP PRIMARY KEY
    ;

DROP INDEX "LRSSCHEMA"."JOBNUM_INDX"
    ;
    
ALTER TABLE "LRSSCHEMA"."GLOBALJOBIDASSIGNMENT" 
    ADD CONSTRAINT "PK_GLOBALJOBIDASS2" PRIMARY KEY ("JOBNUMBER")
    ;

-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBSTATUS"
-----------------------------------------------------------------------

ALTER TABLE "LRSSCHEMA"."JOBSTATUS" 
	ADD "LOGCURRENTPART" VARCHAR(250)
	;
 

-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."RECURRINGREQUEST"
-----------------------------------------------------------------------

ALTER TABLE "LRSSCHEMA"."RECURRINGREQUEST" 
	ADD "NAMEVALUEPAIRS" VARCHAR(2458) NOT NULL DEFAULT ''
	;

UPDATE "LRSSCHEMA"."RECURRINGREQUEST" 
	SET "SUBMITTER"=''
	WHERE "SUBMITTER" IS NULL
	;

-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JMCUSERPREF"
-----------------------------------------------------------------------

CREATE TABLE "LRSSCHEMA"."JMCUSERPREF"  (
	"USERID" VARCHAR(32) NOT NULL , 
	"PREFSCOPE" VARCHAR(32) NOT NULL, 
	"PREFNAME" VARCHAR(64) NOT NULL, 
	"PREFVALUE" VARCHAR(255) NOT NULL )   
	IN "USERSPACE1" ;    


-- DDL Statements for primary key on Table "LRSSCHEMA"."JMCUSERPREF"

ALTER TABLE "LRSSCHEMA"."JMCUSERPREF" 
	ADD CONSTRAINT "PK_JMCUSERPREF" PRIMARY KEY
		("USERID",
		 "PREFSCOPE",
		 "PREFNAME");
		

-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBPROFILE"
-----------------------------------------------------------------------

CREATE TABLE "LRSSCHEMA"."JOBPROFILE"  (
	"JOBCLASS" VARCHAR(250) NOT NULL , 
	"MEANWORK" DOUBLE NOT NULL,
    "MEANSQUAREWORK" DOUBLE NOT NULL, 
    "MEANCUBEWORK" DOUBLE NOT NULL, 
    "MINWORK" DOUBLE NOT NULL, 
    "MAXWORK" DOUBLE NOT NULL, 
    "NUMJOBSAMPLES" DOUBLE NOT NULL, 
    "CONCURRENCYLEVEL" DOUBLE NOT NULL, 
    "MEMORY" DOUBLE NOT NULL, 
	"LASTUPDATE" VARCHAR(64) NOT NULL)
	IN "USERSPACE1" ;    

-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBPROFILE"

ALTER TABLE "LRSSCHEMA"."JOBPROFILE"
	ADD CONSTRAINT "PK_JOBPROFILE" PRIMARY KEY
		("JOBCLASS");	


-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBUSAGE"
-----------------------------------------------------------------------

CREATE TABLE "LRSSCHEMA"."JOBUSAGE"  (
	"JOBID" VARCHAR(250) NOT NULL , 
	"SUBMITTER" VARCHAR(32),
    "CPUCONSUMEDSOFAR" BIGINT NOT NULL, 
    "JOBSTATE" VARCHAR(32) NOT NULL,
    "SERVER" VARCHAR(250) NOT NULL, 
    "NODE" VARCHAR(250) NOT NULL, 
    "STARTTIME" VARCHAR(64) NOT NULL, 
    "LASTUPDATE" VARCHAR(64) NOT NULL, 
    "ACCNTING" CHAR(64) ) 
	IN "USERSPACE1" ;    

-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBUSAGE"
ALTER TABLE "LRSSCHEMA"."JOBUSAGE"
	ADD CONSTRAINT "PK_JOBUSAGE" PRIMARY KEY
	("JOBID","STARTTIME");	
	
	
-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBCLASSMAXCONCJOBS"
-----------------------------------------------------------------------

CREATE TABLE "LRSSCHEMA"."JOBCLASSMAXCONCJOBS"  (
	"JOBCLASSNAME" VARCHAR(250) NOT NULL , 
	"CONCJOBCOUNT" INTEGER NOT NULL )   
	IN "USERSPACE1" ;    

-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBCLASSMAXCONCJOBS"

ALTER TABLE "LRSSCHEMA"."JOBCLASSMAXCONCJOBS" 
	ADD CONSTRAINT "PK_JOBCLSMAXCJOBS" PRIMARY KEY
		("JOBCLASSNAME");


-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBCLASSEXEREC"
-----------------------------------------------------------------------

CREATE TABLE "LRSSCHEMA"."JOBCLASSEXEREC"  (
	"JOBCLASSNAME" VARCHAR(250) NOT NULL , 
	"LASTUPDATE" VARCHAR(250) NOT NULL,
	"JOBID" VARCHAR(250) NOT NULL )   
	IN "USERSPACE1" ;    

-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBCLASSEXEREC"

ALTER TABLE "LRSSCHEMA"."JOBCLASSEXEREC" 
	ADD CONSTRAINT "PK_JOBCLASSEXEREC" PRIMARY KEY
		("JOBID");
		

-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBIDCONTROL"
-----------------------------------------------------------------------

CREATE TABLE "LRSSCHEMA"."JOBIDCONTROL"  (
    "CONTROLNAME" VARCHAR(250) NOT NULL , 
    "CONTROLVALUE" INTEGER NOT NULL )   
    ; 

-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBIDCONTROL"

ALTER TABLE "LRSSCHEMA"."JOBIDCONTROL" 
	ADD CONSTRAINT "PK_JOBIDCONTROL" PRIMARY KEY
		("CONTROLNAME");


-----------------------------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBREDOLIST"
-----------------------------------------------------------------------

CREATE TABLE "LRSSCHEMA"."JOBREDOLIST"  (
    "JOBID" VARCHAR(250) NOT NULL , 
    "EENAME" VARCHAR(250) NOT NULL , 
    "ACTION" VARCHAR(32) NOT NULL )   
    ; 

-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBREDOLIST"

ALTER TABLE "LRSSCHEMA"."JOBREDOLIST" 
	ADD CONSTRAINT "PK_JOBREDOLIST" PRIMARY KEY
		("JOBID", "EENAME");
		

-----------------------------------------------------------------------


COMMIT WORK;


CONNECT RESET;


TERMINATE;
