-- This script migrates XD 6.0.2 Long Running Scheduler tables to XD 6.1 on an Informix instance.
-- This script can be modified if needed to change the name of database or name of the Schema used. 
-- Default database name is LRSCHED and default schema name is LRSSCHEMA.
-- The following command can be issued from Informix command line processor.
-- To run this script type at cmd-line in <informix_install>/bin
-- dbaccess - MigrateLRSCHEDTablesInformix.sql

CONNECT TO "LRSCHED";

-----------------------------------------------------------------------
-- DDL Statements for table LRSSCHEMA.GLOBALJOBIDASSIGNMENT
-----------------------------------------------------------------------

ALTER TABLE LRSSCHEMA.GLOBALJOBIDASSIGNMENT
	ADD JOBCREATETIME VARCHAR(23);

DROP INDEX LRSSCHEMA.JOBNUM_INDX;

ALTER TABLE LRSSCHEMA.GLOBALJOBIDASSIGNMENT
    DROP CONSTRAINT PK_GLOBALJOBIDASS2;

ALTER TABLE LRSSCHEMA.GLOBALJOBIDASSIGNMENT
    ADD CONSTRAINT PRIMARY KEY(JOBNUMBER) CONSTRAINT PK_GLOBALJOBIDASS2;

-----------------------------------------------------------------------
-- DDL Statements for table LRSSCHEMA.JOBSTATUS
-----------------------------------------------------------------------

ALTER TABLE LRSSCHEMA.JOBSTATUS 
	ADD LOGCURRENTPART VARCHAR(250);
 

-----------------------------------------------------------------------
-- DDL Statements for table LRSSCHEMA.RECURRINGREQUEST
-----------------------------------------------------------------------

ALTER TABLE LRSSCHEMA.RECURRINGREQUEST 
	ADD NAMEVALUEPAIRS VARCHAR(255) DEFAULT "" NOT NULL;

UPDATE LRSSCHEMA.RECURRINGREQUEST 
	SET SUBMITTER=''
	WHERE SUBMITTER IS NULL;

------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JMCUSERPREF"
------------------------------------------------

 CREATE TABLE LRSSCHEMA.JMCUSERPREF  (

		  USERID VARCHAR(32) NOT NULL , 
		  
		  PREFSCOPE VARCHAR(32) NOT NULL,

		  PREFNAME VARCHAR(64) NOT NULL, 

		  PREFVALUE VARCHAR(255) NOT NULL    

		 )
                  IN rootdbs;  

-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JMCUSERPREF"
-----------------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JMCUSERPREF
	ADD CONSTRAINT PRIMARY KEY(USERID,PREFSCOPE,PREFNAME) CONSTRAINT PK_JMCUSERPREF;


------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBPROFILE"
------------------------------------------------

 CREATE TABLE LRSSCHEMA.JOBPROFILE  (

		  JOBCLASS VARCHAR(250) NOT NULL , 
		  
		  MEANWORK FLOAT NOT NULL,

          MEANSQUAREWORK FLOAT NOT NULL, 

          MEANCUBEWORK FLOAT NOT NULL, 

          MINWORK FLOAT NOT NULL, 

          MAXWORK FLOAT NOT NULL, 

          NUMJOBSAMPLES FLOAT NOT NULL, 

          CONCURRENCYLEVEL FLOAT NOT NULL, 

          MEMORY FLOAT NOT NULL, 

		  LASTUPDATE VARCHAR(64) NOT NULL    

		 )
                  IN rootdbs;  

-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBPROFILEF"
-----------------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBPROFILE
	ADD CONSTRAINT PRIMARY KEY(JOBCLASS) CONSTRAINT PK_JOBPROFILE;	


------------------------------------------------
-- DDL Statements for table "LRSSCHEMA"."JOBUSAGE"
------------------------------------------------

 CREATE TABLE LRSSCHEMA.JOBUSAGE  (

		  JOBID VARCHAR(250) NOT NULL , 
		  
		  SUBMITTER VARCHAR(32),

          CPUCONSUMEDSOFAR INT8 NOT NULL, 
          
          JOBSTATE VARCHAR(32) NOT NULL,

          SERVER VARCHAR(250) NOT NULL, 

          NODE VARCHAR(250) NOT NULL, 

          STARTTIME VARCHAR(64) NOT NULL, 

          LASTUPDATE VARCHAR(64) NOT NULL, 

          ACCNTING CHAR(64) 

		 )
                  IN rootdbs;  

-----------------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA"."JOBUSAGE"
-----------------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBUSAGE
	ADD CONSTRAINT PRIMARY KEY(JOBID,STARTTIME) CONSTRAINT PK_JOBUSAGE;	
	
------------------------------------------------------------
--DDL statements for table: "LRSSCHEMA.JOBCLASSMAXCONCJOBS
-------------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBCLASSMAXCONCJOBS  (

		  JOBCLASSNAME VARCHAR(250) NOT NULL , 

		  CONCJOBCOUNT INTEGER NOT NULL
                  )
                  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.JOBCLASSMAXCONCJOBS"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBCLASSMAXCONCJOBS
      ADD CONSTRAINT PRIMARY KEY(JOBCLASSNAME) CONSTRAINT PK_JOBCLSMAXCJOBS;


      
------------------------------------------------------------
--DDL statements for table: "LRSSCHEMA.JOBCLASSEXEREC
-------------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBCLASSEXEREC  (

		  JOBCLASSNAME VARCHAR(250) NOT NULL , 

		  LASTUPDATE VARCHAR(250) NOT NULL,
		  
		  JOBID VARCHAR(250) NOT NULL		  
                  )
                  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table: "LRSSCHEMA.JOBCLASSEXEREC"
-----------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBCLASSEXEREC
      ADD CONSTRAINT PRIMARY KEY(JOBID) CONSTRAINT PK_JOBCLASSEXEREC;


------------------------------------------------
-- DDL Statements for table "LRSSCHEMA.JOBIDCONTROL"
------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBIDCONTROL  (

		  CONTROLNAME VARCHAR(250) NOT NULL , 

		  CONTROLVALUE INTEGER NOT NULL
		  
		  )   

		  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA.JOBIDCONTROL"
-------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBIDCONTROL 
	ADD CONSTRAINT PRIMARY KEY(CONTROLNAME) CONSTRAINT  PK_JOBIDCONTROL;


------------------------------------------------
-- DDL Statements for table "LRSSCHEMA.JOBREDOLIST"
------------------------------------------------
CREATE TABLE LRSSCHEMA.JOBREDOLIST  (

		  JOBID VARCHAR(250) NOT NULL , 

		  EENAME VARCHAR(250) NOT NULL , 

		  ACTION VARCHAR(32) NOT NULL

		  )   

		  IN rootdbs;

-------------------------------------------------------------
-- DDL Statements for primary key on Table "LRSSCHEMA.JOBREDOLIST"
-------------------------------------------------------------
ALTER TABLE LRSSCHEMA.JOBREDOLIST 
	ADD CONSTRAINT PRIMARY KEY (JOBID, EENAME) CONSTRAINT PK_JOBREDOLIST;
