-- This script migrates XD 6.0.2 Long Running Scheduler tables to XD 6.1 on an oracle db.
-- This script can be modified if needed to change the name of database or name of the Schema used. 
-- Default database name is LRSCHED and default schema name is LRSSCHEMA.
--
-- 1.Process this script using SQL*Plus
-- 2. Replace all occurrances of @LRSCHED_TABLESPACE@ with a valid tablespace that was 
--    created by the CreateLRSCHEDTablespaceOracle.ddl script.
-- Example: 
--  o  sqlplus username/password@LRSCHED @MigrateLRSCHEDTablesOracle.ddl
--  o  or, at the sqlplus prompt, enter
--     SQL> @MigrateLRSCHEDTablesOracle.ddl

-----------------------------------------------------------------------

-- DDL Statements for table "GLOBALJOBIDASSIGNMENT"

-----------------------------------------------------------------------

ALTER TABLE "GLOBALJOBIDASSIGNMENT" 
	ADD "JOBCREATETIME" VARCHAR(23);

ALTER TABLE "GLOBALJOBIDASSIGNMENT" 
    DROP PRIMARY KEY;

DROP INDEX "JOBNUM_INDX";

ALTER TABLE "GLOBALJOBIDASSIGNMENT" 
    ADD CONSTRAINT "PK_GLOBALJOBIDASS2" PRIMARY KEY ("JOBNUMBER");

------------------------------------------------

-- DDL Statements for table "JOBSTATUS"

------------------------------------------------

ALTER TABLE "JOBSTATUS" 
	ADD "LOGCURRENTPART" VARCHAR(250);
 

-----------------------------------------------------------------------

-- DDL Statements for table "RECURRINGREQUEST"

-----------------------------------------------------------------------

ALTER TABLE "RECURRINGREQUEST" 
	ADD "NAMEVALUEPAIRS" VARCHAR(2682) DEFAULT '' NOT NULL;

UPDATE "RECURRINGREQUEST" 
	SET "SUBMITTER"=''
	WHERE "SUBMITTER" IS NULL;

	
------------------------------------------------

-- DDL Statements for table "JMCUSERPREF"

------------------------------------------------

 CREATE TABLE "JMCUSERPREF"  (
		  "USERID" VARCHAR(32) NOT NULL , 
		  "PREFSCOPE" VARCHAR(32) NOT NULL,
		  "PREFNAME" VARCHAR(64) NOT NULL, 
		  "PREFVALUE" VARCHAR(255) NOT NULL )   
		  TABLESPACE @LRSCHED_TABLESPACE@ ; 


-- DDL Statements for primary key on Table "JMCUSERPREF"

ALTER TABLE "JMCUSERPREF" 
	ADD CONSTRAINT "PK_JMCUSERPREF" PRIMARY KEY
		("USERID","PREFSCOPE","PREFNAME");
		
		
		
------------------------------------------------

-- DDL Statements for table "JOBPROFILE"

------------------------------------------------

 CREATE TABLE "JOBPROFILE"  (
		  "JOBCLASS" VARCHAR(32) NOT NULL , 
		  "MEANWORK" DOUBLE PRECISION NOT NULL,
		  "MEANSQUAREWORK" DOUBLE PRECISION NOT NULL, 
		  "MEANCUBEWORK" DOUBLE PRECISION NOT NULL,		   
		  "MINWORK" DOUBLE PRECISION NOT NULL, 
		  "MAXWORK" DOUBLE PRECISION NOT NULL,
		  "NUMJOBSAMPLES" DOUBLE PRECISION NOT NULL, 
		  "CONCURRENCYLEVEL" DOUBLE PRECISION NOT NULL, 
		  "MEMORY" DOUBLE PRECISION NOT NULL, 
		  "LASTUPDATE" VARCHAR(64) NOT NULL )   
		  TABLESPACE @LRSCHED_TABLESPACE@ ; 


-- DDL Statements for primary key on Table "JOBPROFILE"

ALTER TABLE "JOBPROFILE" 
	ADD CONSTRAINT "PK_JOBPROFILE" PRIMARY KEY
		("JOBCLASS");

------------------------------------------------

-- DDL Statements for table "JOBUSAGE"

------------------------------------------------

 CREATE TABLE "JOBUSAGE"  (
		  "JOBID" VARCHAR(250) NOT NULL, 
		  "SUBMITTER" VARCHAR(32),
		  "CPUCONSUMEDSOFAR" NUMBER NOT NULL, 
		  "JOBSTATE" VARCHAR(32) NOT NULL,		   
		  "SERVER" VARCHAR(250) NOT NULL, 
		  "NODE" VARCHAR(250) NOT NULL, 
		  "STARTTIME" VARCHAR(64) NOT NULL, 
		  "LASTUPDATE" VARCHAR(64) NOT NULL, 
		  "ACCNTING" CHAR(64))   
		  TABLESPACE @LRSCHED_TABLESPACE@ ; 


-- DDL Statements for primary key on Table "JOBUSAGE"

ALTER TABLE "JOBUSAGE" 
	ADD CONSTRAINT "PK_JOBUSAGE" PRIMARY KEY
		("JOBID","STARTTIME");
				

------------------------------------------------

-- DDL Statements for table "JOBCLASSMAXCONCJOBS"

------------------------------------------------

 

 CREATE TABLE "JOBCLASSMAXCONCJOBS"  (
		  "JOBCLASSNAME" VARCHAR(250) NOT NULL , 
		  "CONCJOBCOUNT" INTEGER NOT NULL )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBCLASSMAXCONCJOBS"



ALTER TABLE "JOBCLASSMAXCONCJOBS" 
	ADD CONSTRAINT "PK_JOBCLSMAXCJOBS" PRIMARY KEY
		("JOBCLASSNAME");

------------------------------------------------

-- DDL Statements for table "JOBCLASSEXEREC"

------------------------------------------------

 

 CREATE TABLE "JOBCLASSEXEREC"  (
		  "JOBCLASSNAME" VARCHAR(250) NOT NULL , 
		  "LASTUPDATE" VARCHAR(250) NOT NULL,
		  "JOBID" VARCHAR(250) NOT NULL )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBCLASSEXEREC"



ALTER TABLE "JOBCLASSEXEREC" 
	ADD CONSTRAINT "PK_JOBCLASSEXEREC" PRIMARY KEY
		("JOBID");



		
------------------------------------------------

-- DDL Statements for table "JOBIDCONTROL"

------------------------------------------------

 

 CREATE TABLE "JOBIDCONTROL"  (
		  "CONTROLNAME" VARCHAR(250) NOT NULL , 
		  "CONTROLVALUE" INTEGER NOT NULL )   
          TABLESPACE @LRSCHED_TABLESPACE@ ; 



-- DDL Statements for primary key on Table "JOBIDCONTROL"



ALTER TABLE "JOBIDCONTROL" 
	ADD CONSTRAINT "PK_JOBIDCONTROL" PRIMARY KEY
		("CONTROLNAME");



------------------------------------------------

-- DDL Statements for table "JOBREDOLIST"

------------------------------------------------

 

CREATE TABLE "JOBREDOLIST"  (
		 "JOBID" VARCHAR(250) NOT NULL , 
		 "EENAME" VARCHAR(250) NOT NULL , 
		 "ACTION" VARCHAR(32) NOT NULL )   
		 TABLESPACE @LRSCHED_TABLESPACE@ ; 




-- DDL Statements for primary key on Table "JOBREDOLIST"



ALTER TABLE "JOBREDOLIST" 
	ADD CONSTRAINT "PK_JOBREDOLIST" PRIMARY KEY
		("JOBID", "EENAME");
		
		