#  This program may be used, executed, copied, modified and distributed
#  without royalty for the purpose of developing, using, marketing, or distributing.
#
# script for creating XD default template
#
# author: bkmartin

import sys
import java

nl = java.lang.System.getProperty("line.separator")

startingOverlayTCPPort = 0
startingOverlayUDPPort = 0
endpoints = []
serverEntryTemplates = []
overlayTCPEndpointName = "OVERLAY_TCP_LISTENER_ADDRESS"
overlayUDPEndpointName = "OVERLAY_UDP_LISTENER_ADDRESS"
foundTCP = 0
foundUDP = 0
hostName = "*"


if len(sys.argv) < 2:
    print "Using default Overlay Ports"
    startingOverlayTCPPort = 11001
    startingOverlayUDPPort = 11002
else:
    print "Using passed values for Overlay Ports"
    startingOverlayTCPPort = sys.argv[0]
    startingOverlayUDPPort = sys.argv[1]

print "Starting Overlay TCP Listener Address"
print startingOverlayTCPPort
print "Starting Overlay UDP Listener Address"
print startingOverlayUDPPort

def createEndPoint(serverTemplate, endPointName, endPointHost, endPointPort):
    print "Creating new End Point"
    attrs = []
    namedEndpointAttrs = ["endPointName", endPointName]
    attrs.append(namedEndpointAttrs)
    namedEndPoint = AdminConfig.create("NamedEndPoint", serverTemplate, attrs)
    attrs = []
    hostAttr = ["host", endPointHost]
    portAttr = ["port", endPointPort]
    attrs.append(hostAttr)
    attrs.append(portAttr)
    try:
       newEndPoint = AdminConfig.create("EndPoint", namedEndPoint, attrs)
       print "Successfully created new end point"
    except:
       print "Exception while creating new end point"
           

def convertToList(inlist):
     outlist=[]
     if (len(inlist)>0 and inlist[0]=='[' and inlist[len(inlist)-1]==']'):
        inlist = inlist[1:len(inlist)-1]
        clist = inlist.split(" ")
     else:
        clist = inlist.split("\n")
     for elem in clist:
        elem=elem.rstrip();
        if (len(elem)>0):
           outlist.append(elem)
     return outlist

def getConfigIdForTemplate(templateName):
   templates=convertToList(AdminConfig.listTemplates("Server"))
   for template in templates:
       cname = AdminConfig.showAttribute(template,"name")
       if (cname == templateName):
          return template
   return None
   
def getServerType(serverTemplate):
    tokens = serverTemplate.split("/")
    idx = 0
    for token in tokens:
#      serverTemplate is of the form 'defaultXD(templates/servertypes/APPLICATION_SERVER/servers/defaultXD|server.xml#Server_1210548827522)'
#      return third token 
       if (idx == 2): 
         return token
       idx=idx+1
    return None

print "creating xd template"
template=getConfigIdForTemplate("defaultXD")
if (template == None):
   AdminTask.createTemplateFromTemplate('[-sourceTemplate default -destinationTemplate defaultXD -description "WebSphere XD Default Template"]')
   template=getConfigIdForTemplate("defaultXD")
   threadpools=convertToList(AdminConfig.list("ThreadPool",template))
   for threadpool in threadpools:
      tname = AdminConfig.showAttribute(threadpool,"name")
      if (tname == "WebContainer"):
         print "modifying WebContainer threadpool in xd template"
         AdminConfig.modify(threadpool,[['maximumSize','500']])
else:
   print "template already created"


print "creating xd ZOS template"
template=getConfigIdForTemplate("defaultXDZOS")
if (template == None):
   AdminTask.createTemplateFromTemplate('[-sourceTemplate defaultZOS -destinationTemplate defaultXDZOS -description "WebSphere XD ZOS Default Template"]')
   template=getConfigIdForTemplate("defaultXDZOS")
   threadpools=convertToList(AdminConfig.list("ThreadPool",template))
   for threadpool in threadpools:
      tname = AdminConfig.showAttribute(threadpool,"name")
      if (tname == "WebContainer"):
         print "modifying WebContainer threadpool in xd zOS template"
         AdminConfig.modify(threadpool,[['maximumSize','500']])
else:
   print "template already created"


print "add Overlay Ports to Template"
setname = ""

serverEntryTemplates = convertToList(AdminConfig.listTemplates("ServerEntry"))
for serverEntryTemplate in serverEntryTemplates:
    setname = AdminConfig.showAttribute(serverEntryTemplate,"serverName")
    foundTCP = 0
    foundUDP = 0
    if ((setname == "defaultXD") or (setname == "defaultXDZOS")):
        endpoints = convertToList(AdminConfig.showAttribute(serverEntryTemplate,"specialEndpoints"))
        for endpoint in endpoints:
            epname = AdminConfig.showAttribute(endpoint,"endPointName")
            if (epname == overlayTCPEndpointName):
                foundTCP = 1
                print "found " + epname + " in " + setname
            if (epname == overlayUDPEndpointName):
                foundUDP = 1
                print "found " + epname + " in " + setname

        if (foundTCP == 0):
           print overlayTCPEndpointName + " not found in " + setname
           createEndPoint(serverEntryTemplate, overlayTCPEndpointName, hostName, startingOverlayTCPPort)

        if (foundUDP == 0):
           print overlayUDPEndpointName + " not found in " + setname
           createEndPoint(serverEntryTemplate, overlayUDPEndpointName, hostName, startingOverlayUDPPort)
           
print "Add generic JVM argument '-agentlib:HeapDefect' to application server defaultXD/defaultXDZOS templates and ODR templates"
serverTemplates = convertToList(AdminConfig.listTemplates("Server"))
for serverTemplate in serverTemplates:
    serverType = getServerType(serverTemplate)
    serverTemplateName = AdminConfig.showAttribute(serverTemplate,"name")
    if (((serverTemplateName == "defaultXD" or serverTemplateName == "defaultXDZOS") and 
         (serverType == "APPLICATION_SERVER")) or serverType == "ONDEMAND_ROUTER"):
       procDefs = convertToList(AdminConfig.showAttribute(serverTemplate, "processDefinitions"))
       for procDef in procDefs:
           if (procDef.find("JavaProcessDef") != -1):
              jvmEntries = AdminConfig.showAttribute(procDef, "jvmEntries")
              if (len(jvmEntries)>0 and jvmEntries[0]=='[' and jvmEntries[len(jvmEntries)-1]==']'):
              	  jvmEntries = jvmEntries[1:len(jvmEntries)-1]
              genericArgs = AdminConfig.showAttribute(jvmEntries, "genericJvmArguments")
              if (genericArgs.find("-agentlib:HeapDetect") == -1):
                  genericArgs = "-agentlib:HeapDetect " + genericArgs
                  AdminConfig.modify(jvmEntries, [["genericJvmArguments", genericArgs]])
       
print "saving workspace"
AdminConfig.save()
print "finished."

